@@ -44,7 +44,7 @@ qint64 LyricsModel::LyricsModelPrivate::parseOneTimeStamp(
      * ||| || || ||
      * ||| || || |End
      * ||| || || RightBracket
-     * ||| || |Hundredths
+     * ||| || |Milliseconds
      * ||| || Period
      * ||| |Seconds
      * ||| Colon
@@ -52,9 +52,9 @@ qint64 LyricsModel::LyricsModelPrivate::parseOneTimeStamp(
      * |LeftBracket
      * Start
      * */
-    enum States {Start, LeftBracket, Minutes, Colon, Seconds, Period, Hundredths, RightBracket, End};
+    enum States {Start, LeftBracket, Minutes, Colon, Seconds, Period, Milliseconds, RightBracket, End};
     auto states {States::Start};
-    auto minute {0}, second {0}, hundred {0};
+    auto minute {0}, second {0}, ms {0}, msFactor {100};
 
     while (begin != end) {
         switch (begin->toLatin1()) {
@@ -67,10 +67,10 @@ qint64 LyricsModel::LyricsModelPrivate::parseOneTimeStamp(
                 states = LeftBracket;
             break;
         case ']':
-            begin++;
-            if (states == Hundredths) {
-                return minute * 60 * 1000 + second * 1000 +
-                    hundred * 10; // we return milliseconds
+            ++begin;
+            if (states == Milliseconds) {
+                // we return milliseconds
+                return minute * 60 * 1000 + second * 1000 + ms;
             }
             else {
                 return -1;
@@ -97,15 +97,11 @@ qint64 LyricsModel::LyricsModelPrivate::parseOneTimeStamp(
                         second += begin->digitValue();
                         break;
                     case Period:
-                        states = Hundredths;
+                        states = Milliseconds;
                         [[fallthrough]];
-                    case Hundredths:
-                        // we only parse to hundredth second
-                        if (hundred >= 100) {
-                            break;
-                        }
-                        hundred *= 10;
-                        hundred += begin->digitValue();
+                    case Milliseconds:
+                        ms += begin->digitValue() * msFactor;
+                        msFactor /= 10;
                         break;
                     default:
                         // lyric format is corrupt
@@ -116,7 +112,7 @@ qint64 LyricsModel::LyricsModelPrivate::parseOneTimeStamp(
             }
             break;
         }
-        begin++;
+        ++begin;
     }
 
     // end of lyric and no correct value found
@@ -153,12 +149,6 @@ LyricsModel::LyricsModelPrivate::parseOneLine(QString::const_iterator &begin,
  */
 QString LyricsModel::LyricsModelPrivate::parseTags(QString::const_iterator &begin, QString::const_iterator end)
 {
-    static auto skipTillChar = [](QString::const_iterator begin, QString::const_iterator end, char endChar) {
-        while (begin != end && begin->toLatin1() != endChar) {
-            begin++;
-        }
-        return begin;
-    };
     static std::unordered_map<QString, QString> map = {
         {QStringLiteral("ar"), i18nc("@label musical artist", "Artist")},
         {QStringLiteral("al"), i18nc("@label musical album", "Album")},
@@ -172,43 +162,40 @@ QString LyricsModel::LyricsModelPrivate::parseTags(QString::const_iterator &begi
 
     while (begin != end) {
         // skip till tags
-        begin = skipTillChar(begin, end, '[');
+        begin = std::find(begin, end, '['_L1);
         if (begin != end) {
-            begin++;
+            ++begin;
         }
         else {
             break;
         }
 
-        auto tagIdEnd = skipTillChar(begin, end, ':');
+        auto tagIdEnd = std::find(begin, end, ':'_L1);
         auto tagId = QString(begin, std::distance(begin, tagIdEnd));
         if (tagIdEnd != end &&
             (map.count(tagId) || tagId == QStringLiteral("offset"))) {
-          tagIdEnd++;
+            ++tagIdEnd;
 
-          auto tagContentEnd = skipTillChar(tagIdEnd, end, ']');
-          bool ok = true;
-          if (map.count(tagId)) {
-            tags += i18nc(
-                "@label this is a key => value map", "%1: %2\n", map[tagId],
-                QString(tagIdEnd, std::distance(tagIdEnd, tagContentEnd)));
-          } else {
-            // offset tag
-            offset = QString(tagIdEnd, std::distance(tagIdEnd, tagContentEnd))
-                         .toLongLong(&ok);
-          }
+            auto tagContentEnd = std::find(tagIdEnd, end, ']'_L1);
+            bool ok = true;
+            if (map.count(tagId)) {
+                tags += i18nc("@label this is a key => value map", "%1: %2\n", map[tagId], QString(tagIdEnd, std::distance(tagIdEnd, tagContentEnd)));
+            } else {
+                // offset tag
+                offset = QString(tagIdEnd, std::distance(tagIdEnd, tagContentEnd)).toLongLong(&ok);
+            }
 
-          if (ok) {
-            begin = tagContentEnd;
-          } else {
-            // Invalid offset tag, we step back one to compensate the '[' we
-            // step over
-            begin--;
-            break;
-          }
+            if (ok) {
+                begin = tagContentEnd;
+            } else {
+                // Invalid offset tag, we step back one to compensate the '[' we
+                // step over
+                --begin;
+                break;
+            }
         } else {
           // No tag, we step back one to compensate the '[' we step over
-          begin--;
+          --begin;
           break;
         }
     }
@@ -236,7 +223,7 @@ bool LyricsModel::LyricsModelPrivate::parse(const QString &lyric)
           timeStamp = parseOneTimeStamp(begin, end);
         }
         auto string = parseOneLine(begin, end);
-        if (!string.isEmpty() && !timeStamps.empty()) {
+        if (!timeStamps.empty()) {
             for (auto time : timeStamps) {
                 lyrics.push_back({string, time});
             }
