@@ -16,6 +16,7 @@
 
 #include <QUrl>
 #include <QDir>
+#include <QStandardPaths>
 
 class ViewsListDataPrivate
 {
@@ -25,7 +26,7 @@ public:
                                                ViewManager::ContextView},
                                               {{i18nc("@title:window Title of the view of recently played tracks", "Recently Played")},
                                                QUrl{QStringLiteral("image://icon/media-playlist-play")},
-                                               ViewManager::ListView,
+                                               ViewManager::TrackView,
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::FilterByRecentlyPlayed,
                                                ElisaUtils::Track,
@@ -35,12 +36,10 @@ public:
                                                Qt::DescendingOrder,
                                                {i18nc("@item:inmenu", "Least Recently Played First"), i18nc("@item:inmenu", "Most Recently Played First")},
                                                ViewManager::MultipleAlbum,
-                                               ViewManager::NoDiscHeaders,
-                                               ViewManager::IsTrack,
-                                               ViewManager::IsFlatModel},
+                                               ViewManager::NoDiscHeaders},
                                               {{i18nc("@title:window Title of the view of frequently played tracks", "Frequently Played")},
                                                QUrl{QStringLiteral("image://icon/view-media-playcount")},
-                                               ViewManager::ListView,
+                                               ViewManager::TrackView,
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::FilterByFrequentlyPlayed,
                                                ElisaUtils::Track,
@@ -50,9 +49,7 @@ public:
                                                Qt::DescendingOrder,
                                                {i18nc("@item:inmenu", "Least Frequently Played First"), i18nc("@item:inmenu", "Most Frequently Played First")},
                                                ViewManager::MultipleAlbum,
-                                               ViewManager::NoDiscHeaders,
-                                               ViewManager::IsTrack,
-                                               ViewManager::IsFlatModel},
+                                               ViewManager::NoDiscHeaders},
                                               {{i18nc("@title:window Title of the view of all albums", "Albums")},
                                                QUrl{QStringLiteral("image://icon/view-media-album-cover")},
                                                ViewManager::GridView,
@@ -63,11 +60,10 @@ public:
                                                {DataTypes::TitleRole, DataTypes::ArtistRole, DataTypes::GenreRole, DataTypes::YearRole},
                                                {i18nc("@title:menu", "Title"), i18nc("@title:menu", "Artist"), i18nc("@title:menu", "Genre"), i18nc("@title:menu", "Year")},
                                                Qt::AscendingOrder,
-                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
+                                               {i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
                                                QUrl{QStringLiteral("image://icon/media-default-album")},
                                                ViewManager::DelegateWithSecondaryText,
-                                               ViewManager::ViewShowRating,
-                                               ViewManager::IsFlatModel},
+                                               ViewManager::ViewShowRating},
                                               {{i18nc("@title:window Title of the view of all artists", "Artists")},
                                                QUrl{QStringLiteral("image://icon/view-media-artist")},
                                                ViewManager::GridView,
@@ -78,14 +74,13 @@ public:
                                                {Qt::DisplayRole},
                                                {i18nc("@title:menu", "Name")},
                                                Qt::AscendingOrder,
-                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
+                                               {i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A")},
                                                QUrl{QStringLiteral("image://icon/view-media-artist")},
                                                ViewManager::DelegateWithoutSecondaryText,
-                                               ViewManager::ViewHideRating,
-                                               ViewManager::IsFlatModel},
+                                               ViewManager::ViewHideRating},
                                               {{i18nc("@title:window Title of the view of all tracks", "Tracks")},
                                                QUrl{QStringLiteral("image://icon/view-media-track")},
-                                               ViewManager::ListView,
+                                               ViewManager::TrackView,
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::NoFilter,
                                                ElisaUtils::Track,
@@ -98,13 +93,11 @@ public:
                                                 i18nc("@title:menu", "Year"), i18nc("@title:menu", "Duration"), i18nc("@title:menu", "Composer"), i18nc("@title:menu", "Lyricist"),
                                                 i18nc("@title:menu", "Last Modified")},
                                                Qt::AscendingOrder,
-                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"),
-                                                i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First"), i18nc("@item:inmenu", "Shortest First"), i18nc("@item:inmenu", "Longest First"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"),
+                                               {i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"),
+                                                i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First"), i18nc("@item:inmenu", "Shortest First"), i18nc("@item:inmenu", "Longest First"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"), i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A"),
                                                 i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
                                                ViewManager::MultipleAlbum,
-                                               ViewManager::NoDiscHeaders,
-                                               ViewManager::IsTrack,
-                                               ViewManager::IsFlatModel},
+                                               ViewManager::NoDiscHeaders},
                                               {{i18nc("@title:window Title of the view of all genres", "Genres")},
                                                QUrl{QStringLiteral("image://icon/view-media-genre")},
                                                ViewManager::GridView,
@@ -115,11 +108,10 @@ public:
                                                {Qt::DisplayRole},
                                                {i18nc("@title:menu", "Genre")},
                                                Qt::AscendingOrder,
-                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
+                                               {i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A")},
                                                QUrl{QStringLiteral("image://icon/view-media-genre")},
                                                ViewManager::DelegateWithoutSecondaryText,
-                                               ViewManager::ViewHideRating,
-                                               ViewManager::IsFlatModel},
+                                               ViewManager::ViewHideRating},
                                               {{i18nc("@title:window Title of the file browser view", "Files")},
                                                QUrl{QStringLiteral("image://icon/document-open-folder")},
                                                ViewManager::GridView,
@@ -129,12 +121,11 @@ public:
                                                QUrl{QStringLiteral("image://icon/document-open-folder")},
                                                ViewManager::DelegateWithoutSecondaryText,
                                                ViewManager::ViewHideRating,
-                                               ViewManager::IsFlatModel,
                                                QUrl::fromLocalFile(QDir::rootPath())
                                               },
                                               {{i18nc("@title:window Title of the file radios browser view", "Radio Stations")},
                                                QUrl{QStringLiteral("image://icon/radio")},
-                                               ViewManager::ListView,
+                                               ViewManager::TrackView,
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::NoFilter,
                                                ElisaUtils::Radio,
@@ -142,11 +133,11 @@ public:
                                                {Qt::DisplayRole},
                                                {i18nc("@title:menu", "Name")},
                                                Qt::AscendingOrder,
-                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
+                                               {i18nc("@item:inmenu", "A–Z"), i18nc("@item:inmenu", "Z–A")},
                                                ViewManager::MultipleAlbum,
-                                               ViewManager::NoDiscHeaders,
-                                               ViewManager::IsRadio,
-                                               ViewManager::IsFlatModel}};
+                                               ViewManager::NoDiscHeaders}};
+
+    const int mNumOfBaseViews = mViewsParameters.count();
 
     QMap<ElisaUtils::PlayListEntryType, QUrl> mDefaultIcons = {{ElisaUtils::Album, QUrl{QStringLiteral("image://icon/view-media-album-cover")}},
                                                                {ElisaUtils::Artist, QUrl{QStringLiteral("image://icon/view-media-artist")}},
@@ -154,18 +145,16 @@ public:
 
     ElisaUtils::PlayListEntryType mEmbeddedCategory = ElisaUtils::Unknown;
 
-    ElisaUtils::PlayListEntryType mOldEmbeddedCategory = ElisaUtils::Unknown;
-
     ModelDataLoader *mDataLoader = nullptr;
 
     MusicListenersManager *mManager = nullptr;
 
     DatabaseInterface *mDatabase = nullptr;
-
-    bool mIsFullyInitialized = true;
 };
 
-ViewsListData::ViewsListData(QObject *parent) : QObject(parent), d(std::make_unique<ViewsListDataPrivate>())
+ViewsListData::ViewsListData(QObject *parent)
+    : QObject(parent)
+    , d(std::make_unique<ViewsListDataPrivate>())
 {
     d->mDataLoader = new ModelDataLoader;
     connect(this, &ViewsListData::destroyed, d->mDataLoader, &ModelDataLoader::deleteLater);
@@ -218,30 +207,9 @@ bool ViewsListData::defaultEntry(int index) const
     return d->mEmbeddedCategory == ElisaUtils::Unknown || d->mViewsParameters[index].mEntryType != d->mEmbeddedCategory;
 }
 
-int ViewsListData::indexFromEmbeddedDatabaseId(qulonglong databaseId) const
+ElisaUtils::PlayListEntryType ViewsListData::dataType(int index) const
 {
-    auto result = std::find_if(d->mViewsParameters.begin(), d->mViewsParameters.end(), [this, databaseId](auto data) {
-        return d->mEmbeddedCategory == data.mEntryType && data.mDataFilter.databaseId() == databaseId;
-    });
-
-    if (result == d->mViewsParameters.end()) {
-        return -1;
-    }
-
-    return result - d->mViewsParameters.begin();
-}
-
-int ViewsListData::indexFromEmbeddedName(const QString &name) const
-{
-    auto result = std::find_if(d->mViewsParameters.begin(), d->mViewsParameters.end(), [this, name](auto data) {
-        return d->mEmbeddedCategory == data.mEntryType && data.mMainTitle == name;
-    });
-
-    if (result == d->mViewsParameters.end()) {
-        return -1;
-    }
-
-    return result - d->mViewsParameters.begin();
+    return d->mViewsParameters[index].mDataType;
 }
 
 ElisaUtils::PlayListEntryType ViewsListData::embeddedCategory() const
@@ -251,32 +219,12 @@ ElisaUtils::PlayListEntryType ViewsListData::embeddedCategory() const
 
 void ViewsListData::setEmbeddedCategory(ElisaUtils::PlayListEntryType aEmbeddedView)
 {
-    if (d->mEmbeddedCategory != aEmbeddedView)
-    {
-        d->mOldEmbeddedCategory = d->mEmbeddedCategory;
+    if (d->mEmbeddedCategory != aEmbeddedView) {
         d->mEmbeddedCategory = aEmbeddedView;
 
         Q_EMIT embeddedCategoryChanged();
 
         refreshEmbeddedCategory();
-
-        switch (d->mEmbeddedCategory) {
-        case ElisaUtils::Composer:
-        case ElisaUtils::Container:
-        case ElisaUtils::FileName:
-        case ElisaUtils::Lyricist:
-        case ElisaUtils::Radio:
-        case ElisaUtils::Track:
-        case ElisaUtils::Unknown:
-            d->mIsFullyInitialized = true;
-            Q_EMIT isFullyInitializedChanged();
-            break;
-        case ElisaUtils::Album:
-        case ElisaUtils::Artist:
-        case ElisaUtils::Genre:
-        case ElisaUtils::PlayList:
-            break;
-        }
     }
 }
 
@@ -305,9 +253,6 @@ void ViewsListData::genresAdded(const DataTypes::ListGenreDataType &newData)
                                        ViewManager::ViewHideRating});
     }
     Q_EMIT dataAdded();
-
-    d->mIsFullyInitialized = true;
-    Q_EMIT isFullyInitializedChanged();
 }
 
 void ViewsListData::artistsAdded(const DataTypes::ListArtistDataType &newData)
@@ -335,27 +280,6 @@ void ViewsListData::artistsAdded(const DataTypes::ListArtistDataType &newData)
                                        ViewManager::ViewShowRating});
     }
     Q_EMIT dataAdded();
-
-    d->mIsFullyInitialized = true;
-    Q_EMIT isFullyInitializedChanged();
-}
-
-void ViewsListData::artistRemoved(qulonglong removedDatabaseId)
-{
-    if (d->mEmbeddedCategory != ElisaUtils::Artist) {
-        return;
-    }
-
-    for (int i = 0; i < d->mViewsParameters.count(); ++i) {
-        const auto &data = d->mViewsParameters[i];
-
-        if (data.mDataFilter.databaseId() == removedDatabaseId) {
-            Q_EMIT dataAboutToBeRemoved(i, i);
-            d->mViewsParameters.removeAt(i);
-            Q_EMIT dataRemoved();
-            break;
-        }
-    }
 }
 
 void ViewsListData::albumsAdded(const DataTypes::ListAlbumDataType &newData)
@@ -377,7 +301,7 @@ void ViewsListData::albumsAdded(const DataTypes::ListAlbumDataType &newData)
 
         d->mViewsParameters.push_back({oneAlbum.title(),
                                        coverImage,
-                                       ViewManager::ListView,
+                                       ViewManager::TrackView,
                                        ViewManager::GenericDataModel,
                                        ElisaUtils::FilterById,
                                        oneAlbum.databaseId(),
@@ -387,33 +311,11 @@ void ViewsListData::albumsAdded(const DataTypes::ListAlbumDataType &newData)
                                        {Qt::DisplayRole},
                                        {QStringLiteral("Title")},
                                        Qt::AscendingOrder,
-                                       {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
+                                       {QStringLiteral("A–Z"), QStringLiteral("Z–A")},
                                        ViewManager::SingleAlbum,
-                                       ViewManager::DiscHeaders,
-                                       ViewManager::IsTrack});
+                                       ViewManager::DiscHeaders});
     }
     Q_EMIT dataAdded();
-
-    d->mIsFullyInitialized = true;
-    Q_EMIT isFullyInitializedChanged();
-}
-
-void ViewsListData::albumRemoved(qulonglong removedDatabaseId)
-{
-    if (d->mEmbeddedCategory != ElisaUtils::Album) {
-        return;
-    }
-
-    for (int i = 0; i < d->mViewsParameters.count(); ++i) {
-        const auto &data = d->mViewsParameters[i];
-
-        if (data.mDataFilter.databaseId() == removedDatabaseId) {
-            Q_EMIT dataAboutToBeRemoved(i, i);
-            d->mViewsParameters.removeAt(i);
-            Q_EMIT dataRemoved();
-            break;
-        }
-    }
 }
 
 void ViewsListData::albumModified(const DataTypes::AlbumDataType &modifiedAlbum)
@@ -440,96 +342,44 @@ void ViewsListData::albumModified(const DataTypes::AlbumDataType &modifiedAlbum)
     }
 }
 
+void ViewsListData::databaseEntryRemoved(qulonglong removedDatabaseId, ElisaUtils::PlayListEntryType entryType)
+{
+    if (d->mEmbeddedCategory != entryType) {
+        return;
+    }
+
+    for (int i = 0; i < d->mViewsParameters.count(); ++i) {
+        const auto &data = d->mViewsParameters[i];
+
+        if (data.mDataFilter.databaseId() == removedDatabaseId) {
+            Q_EMIT dataAboutToBeRemoved(i, i);
+            d->mViewsParameters.removeAt(i);
+            Q_EMIT dataRemoved();
+            break;
+        }
+    }
+}
+
+void ViewsListData::clearEmbeddedItems()
+{
+    if (d->mViewsParameters.count() > d->mNumOfBaseViews) {
+        const int startIndex = d->mNumOfBaseViews;
+        const int numToRemove = d->mViewsParameters.count() - startIndex;
+        Q_EMIT dataAboutToBeRemoved(startIndex, d->mViewsParameters.count() - 1);
+        d->mViewsParameters.remove(startIndex, numToRemove);
+        Q_EMIT dataRemoved();
+    }
+}
+
 void ViewsListData::cleanedDatabase()
 {
     qCDebug(orgKdeElisaViews) << "ViewsListData::cleanedDatabase" << d->mEmbeddedCategory;
-
-    switch (d->mEmbeddedCategory)
-    {
-    case ElisaUtils::Album:
-    case ElisaUtils::Genre:
-    case ElisaUtils::Artist:
-        Q_EMIT dataAboutToBeReset();
-        for (int i = 0; i < d->mViewsParameters.size(); ) {
-            if (d->mViewsParameters.at(i).mEntryType == d->mEmbeddedCategory) {
-                d->mViewsParameters.removeAt(i);
-            } else {
-                ++i;
-            }
-        }
-        Q_EMIT dataReset();
-        break;
-    case ElisaUtils::Radio:
-    case ElisaUtils::Track:
-    case ElisaUtils::Unknown:
-    case ElisaUtils::Composer:
-    case ElisaUtils::FileName:
-    case ElisaUtils::Lyricist:
-    case ElisaUtils::Container:
-    case ElisaUtils::PlayList:
-        break;
-    }
+    clearEmbeddedItems();
 }
 
 void ViewsListData::refreshEmbeddedCategory()
 {
-    auto elementsCategoryToRemove = ElisaUtils::Unknown;
-
-    switch (d->mOldEmbeddedCategory)
-    {
-    case ElisaUtils::Album:
-    case ElisaUtils::Artist:
-    case ElisaUtils::Genre:
-        elementsCategoryToRemove = d->mOldEmbeddedCategory;
-        for (int i = 0; i < d->mViewsParameters.size(); ) {
-            if (d->mViewsParameters.at(i).mEntryType == elementsCategoryToRemove) {
-                Q_EMIT dataAboutToBeRemoved(i, i);
-                d->mViewsParameters.removeAt(i);
-                Q_EMIT dataRemoved();
-            } else {
-                ++i;
-            }
-        }
-        break;
-    case ElisaUtils::Radio:
-    case ElisaUtils::Track:
-    case ElisaUtils::Unknown:
-    case ElisaUtils::Composer:
-    case ElisaUtils::FileName:
-    case ElisaUtils::Lyricist:
-    case ElisaUtils::Container:
-    case ElisaUtils::PlayList:
-        break;
-    }
-
-    auto categoryToRemove = ElisaUtils::Unknown;
-
-    switch (d->mEmbeddedCategory)
-    {
-    case ElisaUtils::Album:
-    case ElisaUtils::Genre:
-    case ElisaUtils::Artist:
-        categoryToRemove = d->mEmbeddedCategory;
-        for (int i = 0; i < d->mViewsParameters.size(); ) {
-            if (d->mViewsParameters.at(i).mDataType == categoryToRemove) {
-                Q_EMIT dataAboutToBeRemoved(i, i);
-                d->mViewsParameters.removeAt(i);
-                Q_EMIT dataRemoved();
-            } else {
-                ++i;
-            }
-        }
-        break;
-    case ElisaUtils::Radio:
-    case ElisaUtils::Track:
-    case ElisaUtils::Unknown:
-    case ElisaUtils::Composer:
-    case ElisaUtils::FileName:
-    case ElisaUtils::Lyricist:
-    case ElisaUtils::Container:
-    case ElisaUtils::PlayList:
-        break;
-    }
+    clearEmbeddedItems();
 
     switch (d->mEmbeddedCategory)
     {
@@ -548,76 +398,6 @@ void ViewsListData::refreshEmbeddedCategory()
     case ElisaUtils::PlayList:
         break;
     }
-
-    switch (d->mOldEmbeddedCategory)
-    {
-    case ElisaUtils::Album:
-        Q_EMIT dataAboutToBeAdded(3, 3);
-        d->mViewsParameters.insert(3, {{i18nc("@title:window Title of the view of all albums", "Albums")},
-                                       QUrl{QStringLiteral("image://icon/view-media-album-cover")},
-                                       ViewManager::GridView,
-                                       ViewManager::GenericDataModel,
-                                       ElisaUtils::NoFilter,
-                                       ElisaUtils::Album,
-                                       Qt::DisplayRole,
-                                       {DataTypes::TitleRole, DataTypes::ArtistRole, DataTypes::GenreRole, DataTypes::YearRole},
-                                       {i18nc("@title:menu", "Title"), i18nc("@title:menu", "Artist"), i18nc("@title:menu", "Genre"), i18nc("@title:menu", "Year")},
-                                       Qt::AscendingOrder,
-                                       {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
-                                       QUrl{QStringLiteral("image://icon/media-default-album")},
-                                       ViewManager::DelegateWithSecondaryText,
-                                       ViewManager::ViewShowRating,
-                                       ViewManager::IsFlatModel});
-        Q_EMIT dataAdded();
-        break;
-    case ElisaUtils::Artist:
-        Q_EMIT dataAboutToBeAdded(4, 4);
-        d->mViewsParameters.insert(4, {{i18nc("@title:window Title of the view of all artists", "Artists")},
-                                       QUrl{QStringLiteral("image://icon/view-media-artist")},
-                                       ViewManager::GridView,
-                                       ViewManager::GenericDataModel,
-                                       ElisaUtils::NoFilter,
-                                       ElisaUtils::Artist,
-                                       Qt::DisplayRole,
-                                       {Qt::DisplayRole},
-                                       {i18nc("@title:menu", "Name")},
-                                       Qt::AscendingOrder,
-                                       {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
-                                       QUrl{QStringLiteral("image://icon/view-media-artist")},
-                                       ViewManager::DelegateWithoutSecondaryText,
-                                       ViewManager::ViewHideRating,
-                                       ViewManager::IsFlatModel});
-        Q_EMIT dataAdded();
-        break;
-    case ElisaUtils::Genre:
-        Q_EMIT dataAboutToBeAdded(6, 6);
-        d->mViewsParameters.insert(6, {{i18nc("@title:window Title of the view of all genres", "Genres")},
-                                       QUrl{QStringLiteral("image://icon/view-media-genre")},
-                                       ViewManager::GridView,
-                                       ViewManager::GenericDataModel,
-                                       ElisaUtils::NoFilter,
-                                       ElisaUtils::Genre,
-                                       Qt::DisplayRole,
-                                       {Qt::DisplayRole},
-                                       {i18nc("@title:menu", "Genre")},
-                                       Qt::AscendingOrder,
-                                       {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
-                                       QUrl{QStringLiteral("image://icon/view-media-genre")},
-                                       ViewManager::DelegateWithoutSecondaryText,
-                                       ViewManager::ViewHideRating,
-                                       ViewManager::IsFlatModel});
-        Q_EMIT dataAdded();
-        break;
-    case ElisaUtils::Radio:
-    case ElisaUtils::Track:
-    case ElisaUtils::Unknown:
-    case ElisaUtils::Composer:
-    case ElisaUtils::FileName:
-    case ElisaUtils::Lyricist:
-    case ElisaUtils::Container:
-    case ElisaUtils::PlayList:
-        break;
-    }
 }
 
 MusicListenersManager* ViewsListData::manager() const
@@ -640,11 +420,6 @@ DatabaseInterface* ViewsListData::database() const
     return d->mDatabase;
 }
 
-bool ViewsListData::isFullyInitialized() const
-{
-    return d->mIsFullyInitialized;
-}
-
 void ViewsListData::setDatabase(DatabaseInterface *aDatabase)
 {
     if (d->mDatabase != aDatabase) {
@@ -661,14 +436,19 @@ void ViewsListData::setDatabase(DatabaseInterface *aDatabase)
                 this, &ViewsListData::genresAdded);
         connect(d->mDatabase, &DatabaseInterface::genresAdded,
                 this, &ViewsListData::genresAdded);
+        connect(d->mDatabase, &DatabaseInterface::genreRemoved, this, [this](qulonglong databaseId) {
+            databaseEntryRemoved(databaseId, ElisaUtils::Genre);
+        });
         connect(d->mDatabase, &DatabaseInterface::artistsAdded,
                 this, &ViewsListData::artistsAdded);
-        connect(d->mDatabase, &DatabaseInterface::artistRemoved,
-                this, &ViewsListData::artistRemoved);
+        connect(d->mDatabase, &DatabaseInterface::artistRemoved, this, [this](qulonglong databaseId) {
+            databaseEntryRemoved(databaseId, ElisaUtils::Artist);
+        });
         connect(d->mDatabase, &DatabaseInterface::albumsAdded,
                 this, &ViewsListData::albumsAdded);
-        connect(d->mDatabase, &DatabaseInterface::albumRemoved,
-                this, &ViewsListData::albumRemoved);
+        connect(d->mDatabase, &DatabaseInterface::albumRemoved, this, [this](qulonglong databaseId) {
+            databaseEntryRemoved(databaseId, ElisaUtils::Album);
+        });
         connect(d->mDatabase, &DatabaseInterface::albumModified,
                 this, &ViewsListData::albumModified);
         connect(d->mDatabase, &DatabaseInterface::cleanedDatabase,
